==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/SourceCodeOptions.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Options for `SourceCodeFile`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.442Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.SourceCodeOptions")
@software.amazon.jsii.Jsii.Proxy(SourceCodeOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface SourceCodeOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Indentation size.
     * <p>
     * Default: 2
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Number getIndent() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link SourceCodeOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SourceCodeOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<SourceCodeOptions> {
        java.lang.Number indent;

        /**
         * Sets the value of {@link SourceCodeOptions#getIndent}
         * @param indent Indentation size.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder indent(java.lang.Number indent) {
            this.indent = indent;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SourceCodeOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public SourceCodeOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link SourceCodeOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SourceCodeOptions {
        private final java.lang.Number indent;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.indent = software.amazon.jsii.Kernel.get(this, "indent", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.indent = builder.indent;
        }

        @Override
        public final java.lang.Number getIndent() {
            return this.indent;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getIndent() != null) {
                data.set("indent", om.valueToTree(this.getIndent()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.SourceCodeOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SourceCodeOptions.Jsii$Proxy that = (SourceCodeOptions.Jsii$Proxy) o;

            return this.indent != null ? this.indent.equals(that.indent) : that.indent == null;
        }

        @Override
        public final int hashCode() {
            int result = this.indent != null ? this.indent.hashCode() : 0;
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/SourceCodeOptions.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Options for <code>SourceCodeFile</code>.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.152Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.SourceCodeOptions")
@software.amazon.jsii.Jsii.Proxy(SourceCodeOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface SourceCodeOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Indentation size.
     * <p>
     * Default: 2
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Number getIndent() {
        return null;
    }

    /**
     * (experimental) Whether the generated file should be readonly.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getReadonly() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link SourceCodeOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SourceCodeOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<SourceCodeOptions> {
        java.lang.Number indent;
        java.lang.Boolean readonly;

        /**
         * Sets the value of {@link SourceCodeOptions#getIndent}
         * @param indent Indentation size.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder indent(java.lang.Number indent) {
            this.indent = indent;
            return this;
        }

        /**
         * Sets the value of {@link SourceCodeOptions#getReadonly}
         * @param readonly Whether the generated file should be readonly.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder readonly(java.lang.Boolean readonly) {
            this.readonly = readonly;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SourceCodeOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public SourceCodeOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link SourceCodeOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SourceCodeOptions {
        private final java.lang.Number indent;
        private final java.lang.Boolean readonly;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.indent = software.amazon.jsii.Kernel.get(this, "indent", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.readonly = software.amazon.jsii.Kernel.get(this, "readonly", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.indent = builder.indent;
            this.readonly = builder.readonly;
        }

        @Override
        public final java.lang.Number getIndent() {
            return this.indent;
        }

        @Override
        public final java.lang.Boolean getReadonly() {
            return this.readonly;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getIndent() != null) {
                data.set("indent", om.valueToTree(this.getIndent()));
            }
            if (this.getReadonly() != null) {
                data.set("readonly", om.valueToTree(this.getReadonly()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.SourceCodeOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SourceCodeOptions.Jsii$Proxy that = (SourceCodeOptions.Jsii$Proxy) o;

            if (this.indent != null ? !this.indent.equals(that.indent) : that.indent != null) return false;
            return this.readonly != null ? this.readonly.equals(that.readonly) : that.readonly == null;
        }

        @Override
        public final int hashCode() {
            int result = this.indent != null ? this.indent.hashCode() : 0;
            result = 31 * result + (this.readonly != null ? this.readonly.hashCode() : 0);
            return result;
        }
    }
}
